@@ -28,6 +28,7 @@ public:
 Q_SIGNALS:
     Q_SCRIPTABLE void doNotDisturbChanged();
     Q_SCRIPTABLE void isActionDrawerOpenChanged();
+    Q_SCRIPTABLE void panelStateChanged();
     Q_SCRIPTABLE void isTaskSwitcherVisibleChanged();
     Q_SCRIPTABLE void openActionDrawerRequested();
     Q_SCRIPTABLE void closeActionDrawerRequested();
@@ -44,6 +45,10 @@ public Q_SLOTS:
     Q_SCRIPTABLE bool isActionDrawerOpen();
     Q_SCRIPTABLE void setIsActionDrawerOpen(bool value);
 
+    Q_SCRIPTABLE QString panelState();
+    Q_SCRIPTABLE void setPanelState(QString state);
+
+
     Q_SCRIPTABLE bool isTaskSwitcherVisible();
     Q_SCRIPTABLE void setIsTaskSwitcherVisible(bool value);
 
@@ -65,5 +70,7 @@ private:
     bool m_isActionDrawerOpen{false};
     bool m_isTaskSwitcherVisible{false};
 
+    QString m_panelState{};
+
     StartupFeedbackModel *m_startupFeedbackModel{nullptr};
 };
